@@ -368,12 +368,12 @@ fset SCRIPT_LOAD " \0030,4 SCRIPT \003 Loading\003$::dynamic::theme_default_fore
 
 # This is displayed if a mode is missing a required parameter.
 # 0 is a - or + and 1 is the mode letter.
-fset NO_MODE_PARAMETER " \0030,5 ERROR \003 No parameter given for mode change %0%1.  This is likely due to a bug in the IRCd.  If you don't believe it to be the IRCd's fault, please contact patearl@pobox.com with an explaination.  Sending a channel mode request to ensure correct modes." [flocation status]
+fset NO_MODE_PARAMETER " \0030,5 ERROR \003 No parameter given for mode change %0%1.  This is likely due to a bug in the IRCd.  If you don't believe it to be the IRCd's fault, please contact quirc@patearl.net with an explaination.  Sending a channel mode request to ensure correct modes." [flocation status]
 
 # This is displayed if a 324 mode numeric is missing a required parameter when
 # we are on the channel.
 # 0 is a - or + and 1 is the mode letter.
-fset NO_324_MODE_PARAMETER " \0030,5 ERROR \003 No parameter given for mode change %0%1 resulting from a 324 numeric.  This is likely due to a bug in the IRCd.  If you don't believe it to be the IRCd's fault, please contact patearl@pobox.com with an explaination.  The channel modes as stored by QuIRC may not be correct any longer." [flocation status]
+fset NO_324_MODE_PARAMETER " \0030,5 ERROR \003 No parameter given for mode change %0%1 resulting from a 324 numeric.  This is likely due to a bug in the IRCd.  If you don't believe it to be the IRCd's fault, please contact quirc@patearl.net with an explaination.  The channel modes as stored by QuIRC may not be correct any longer." [flocation status]
 
 # This is used by /me to display outgoing actions.
 # 0 is the pathname of the action, 1 is the message.
