@@ -1085,7 +1085,7 @@ void tserver::handle(int mask) {
 	    strcat(buffer,temp);
 	    usedata();
 	  } else {
-	    echo("Buffer Overrun in SERVER (Please contact author at patearl@pobox.com)",".main",1);
+	    echo("Buffer Overrun in SERVER (Please contact author at quirc@patearl.net)",".main",1);
 	  }
 	} else {
 	  disconnect(0);
