@@ -87,7 +87,7 @@ int TT_Proc___template__acceptlist(TT_PROC_ARGS) {
       if(argc==8) {
 	windowp->server->script("event_dcc_accept","s q q q q q","send",num,argv[4],inet_ntoa(in),argv[6],argv[7]);
       }
-      if(argc==9&&(!strlen(argv[8])||!atoi(argv[8]))) {
+      if(argc==9&&(strcmp(argv[8],"0")&&!atoi(argv[8]))) {
 	Tcl_SetResult(interp,"acceptlist: Invalid arguments given",TCL_VOLATILE);
 	return TCL_ERROR;
       }
